@@ -225,12 +225,16 @@ settings_command_changed (GSettings *settings, gchar *key, CommandApplet *comman
 
     cmdline = g_settings_get_string (command_applet->settings, COMMAND_KEY);
     if (strlen (cmdline) == 0 || g_strcmp0(command_applet->cmdline, cmdline) == 0)
+    {
+        g_free (cmdline);
         return;
+    }
 
     if (!g_shell_parse_argv (cmdline, NULL, &argv, &error))
     {
         gtk_label_set_text (command_applet->label, ERROR_OUTPUT);
         g_clear_error (&error);
+        g_free (cmdline);
         return;
     }
     g_strfreev(argv);
@@ -407,6 +411,7 @@ static gboolean
 command_applet_fill (MatePanelApplet* applet)
 {
     CommandApplet *command_applet;
+    AtkObject *atk_widget;
 
     g_set_application_name (_("Command Applet"));
     gtk_window_set_default_icon_name (APPLET_ICON);
@@ -464,6 +469,14 @@ command_applet_fill (MatePanelApplet* applet)
                      "visible",
                      G_SETTINGS_BIND_DEFAULT);
 
+    atk_widget = gtk_widget_get_accessible (command_applet->applet);
+    if (GTK_IS_ACCESSIBLE (atk_widget)) {
+        atk_object_set_name (atk_widget,
+                             _("Command applet"));
+        atk_object_set_description (atk_widget,
+                                    _("Shows the output of a command"));
+    }
+
     /* set up context menu */
     GtkActionGroup *action_group = gtk_action_group_new ("Command Applet Actions");
     gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
